function [t,X] = TogashiKaneko(n,D,V,X0,T,Tlim)
%TogashiKaneko Simulation of stochastic Togashi-Kaneko reaction system
% Inputs:
%   n = species number
%   D = diffusion constant
%   V = volume parameter
%   X0 = initial state, n x 1
%   T = time axis limit
%   Tlim = computational time limit
% Outputs:
%   t = vector of time instants, 1 x Nt
%   X = realized process matrix, n x Nt

% initial state
if nargin < 4
    X0 = V*ones(n,1);
end

% time limit
if nargin < 5
    T = Inf;
end

% computational time limit
% default value 30 s
if nargin < 6
    Tlim = 30;
end

% circulant matrix
M = - eye(n) + diag(ones(1,n-1),-1);
M(1,n) = 1;

% stochiometric matrix
S = [M eye(n) -eye(n)];

% reaction substrates matrix
Sub = [abs(M) zeros(n,n) eye(n)];

% reaction rate constants
kappa = [ones(1,n)/V V*D*ones(1,n) D*ones(1,n)];

% simulation algorithm
[t,X] = Gillespie(S,kappa,Sub,X0,T,Tlim);
%[t,X] = NextReaction(S,kappa,Sub,X0,Inf,Tlim);
    
end
